@@ -4,7 +4,8 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
 
   # ===========================================================================
   ##author<<
-  ## Sebastian Kreutzer, JLU Giessen (Germany), Michael Dietze (GFZ Potsdam)
+  ## Michael Dietze (GFZ Potsdam), \cr
+  ## Sebastian Kreutzer, JLU Giessen (Germany), \cr
   
   ##section<<
   ##version 0.4.1
@@ -14,60 +15,70 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
   ### \code{\link{data.frame}} or \code{\linkS4class{RLum.Results}} object (required): 
   ### for \code{data.frame}: two columns: De 
   ### (\code{values[,1]}) and De error (\code{values[,2]})
+  
   na.exclude = TRUE,
   ### \code{\link{logical}} (with default): excludes \code{NA} values from the 
   ### data set prior to any further operations.
+  
   mtext,
   ### \code{\link{character}} (optional): further sample information 
   ### (\link{mtext}).
+  
   cex.global,
   ### \code{\link{numeric}} (with default): global scaling factor.
+  
   breaks,
   ### (with default): sets breakpoints for histogram. Works as in \link{hist}.
+  
   se,
   ### \code{\link{logical}} (optional): plots standard error points over the 
   ### histogram, default is \code{FALSE}.
+  
   rug,
   ### \code{\link{logical}} (optional): adds rugs to the histogram, default is 
   ### \code{TRUE}.
+  
   normal_curve,
   ### \code{\link{logical}} (with default): adds a normal curve to the histogram. 
   ### Mean and sd are calculated from the input data. More see details section.
+  
   summary,
   ### \code{\link{character}} (optional): adds numerical output to the plot. Can 
-  ### be one or more out of: "n" (number of samples), "mean" (mean De value), 
-  ### "median" (median of the De values), "kdemax" (maximum value of probability 
-  ### density function), "sdrel" (relative standard deviation), "sdabs" 
-  ### (absolute standard deviation), "serel" (relative standard error) and 
-  ### "seabs" (absolute standard deviation).
+  ### be one or more out of: \code{"n"} (number of samples), \code{"mean"} (mean De value), 
+  ### \code{"median"} (median of the De values), \code{"kdemax"} (maximum value of probability 
+  ### density function), \code{"sdrel"} (relative standard deviation), \code{"sdabs"} 
+  ### (absolute standard deviation), \code{"serel"} (relative standard error) and 
+  ### \code{"seabs"} (absolute standard deviation).
+  
   summary.pos,
   ### \code{\link{numeric}} (with default): optional position coordinates for 
   ### the statistical summary. Y-coordinate refers to the right hand y-axis.
+  
   colour,
   ### \code{\link{numeric}} or \link{character} (with default): optional vector 
   ### of length 4 which specifies the colours of the following plot items in 
   ### exactly this order: histogram bars, rug lines, normal distribution curve 
-  ### and standard error points (e.g., c("grey", "black", "red", "grey")).
+  ### and standard error points\cr
+  ### (e.g., \code{c("grey", "black", "red", "grey")}).
+  
   ...
   ### further arguments and graphical parameters passed to \code{\link{plot}}. 
   ### If y-axis labels are provided, these must be specified as a vector of 
-  ### length 2 since the plot features two axes (e.g. \code{xlab = c("axis 
-  ### label 1", "axis label 2")}).
+  ### length 2 since the plot features two axes (e.g. \code{ylab = c("axis 
+  ### label 1", "axis label 2")}). Y-axes limits (\code{ylim}) must be
+  ### provided as vector of length four, with the first two elements specifying
+  ### the left axes limits and the latter two elements giving the right axis
+  ### limits.
 ) {
   
   # Integrity tests ---------------------------------------------------------
-  if(is(values, "RLum.Results") == TRUE){
-    
+  if(is(values, "RLum.Results") == TRUE) {
     values <- get_RLum.Results(values)
-    
-  }else if(is(values, "data.frame") == FALSE){
-    
-    stop("[plot_Histogramm] Error: 'values' has to be an 'RLum.Results' object or 
-         a 'data.frame'.")
-    
+  } else if(is(values, "data.frame") == FALSE) {
+    stop("[plot_Histogramm] Error: 'values' has to be an 
+          'RLum.Results' object or a 'data.frame'.")
   }
   
-  
   ## Set general parameters ---------------------------------------------------
   ## Check/set default parameters
   if(missing(cex.global) == TRUE) {cex.global = 1}
@@ -100,14 +111,14 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
  xlab.plot <- if("xlab" %in% names(extraArgs)) {
     extraArgs$xlab
     } else {
-      expression(paste(D[e], " [unknown unit]"))
+      expression(paste(D[e], " [Gy]"))
     }
   
   ylab.plot <- if("ylab" %in% names(extraArgs)) {
     extraArgs$ylab
     } else {
-      c("Density",
-        "Standard Error")
+      c("Counts",
+        "Error")
     }
   
   breaks.plot <- if("breaks" %in% names(extraArgs)) {
@@ -121,7 +132,21 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
   } else {
     range(breaks.plot)
   }
-
+ 
+ ylim.plot <- if("ylim" %in% names(extraArgs)) {
+   extraArgs$ylim
+ } else {
+   H.lim <- hist(values[,1],
+                 breaks = breaks.plot,
+                 plot = FALSE)
+   if(normal_curve == TRUE) {
+     left.ylim <- c(0, max(H.lim$density))
+   } else {
+     left.ylim <- c(0, max(H.lim$counts))
+   }
+   c(left.ylim, range(values[,2]))
+ }
+  
   pch.plot <- if("pch" %in% names(extraArgs)) {
     extraArgs$pch
   } else {
@@ -129,19 +154,25 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
   }
   
   ## Set plot area format
-  par(oma = c(0,0,0,2),
-      cex=cex.global)
+  par(oma = c(1, 1, 1, 3),
+      cex = cex.global)
 
   ## Plot histogram -----------------------------------------------------------
-  hist(values[,1],
-	  	 main = main.plot,
+  HIST <- hist(values[,1],
+	  	 main = "",
        xlab = xlab.plot,
        ylab = ylab.plot[1],
        xlim = xlim.plot,
+       ylim = ylim.plot[1:2],
        breaks = breaks.plot,
        freq = !normal_curve,
        col = colour[1]
-  )
+       )
+ 
+  
+  ## add title
+  title(line = 2, 
+        main = main.plot)
   
   ## Optionally, add rug ------------------------------------------------------
   if(rug == TRUE) {rug(values[,1], col = colour[2])}
@@ -166,6 +197,7 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
     par(new = TRUE)
     plot(values[,1:2],
          xlim = xlim.plot,
+         ylim = ylim.plot[3:4],
          pch = pch.plot,
          col = colour[4],
          main = "",
@@ -188,8 +220,9 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
   
   ## Optionally add user-defined mtext
   mtext(side = 3,
-          text = mtext,
-          cex = 0.8 * cex.global) 
+        line = 0.5,
+        text = mtext,
+        cex = 0.8 * cex.global) 
   
   ## Optionally add statistical summary ---------------------------------------
   ## Calculate statistical summary
@@ -211,6 +244,12 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
                                    "\n", 
                                    sep = ""),
                              ""),
+                      ifelse("mean.weighted" %in% summary == TRUE,
+                             paste("weighted mean = ", 
+                                   round(weighted.mean(values[,1]), 2), 
+                                   "\n", 
+                                   sep = ""),
+                             ""),
                       ifelse("median" %in% summary == TRUE,
                              paste("median = ", 
                                    round(median_De, 2), 
@@ -242,13 +281,47 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
                                    sep = ""),
                              ""),
                       sep = "")
+
+  ## convert keywords into summary placement coordinates
+  if(missing(summary.pos) == TRUE) {
+    summary.pos <- c(xlim.plot[1], ylim.plot[4])
+    summary.adj <- c(0, 1)
+  } else if(length(summary.pos) == 2) {
+    summary.pos <- summary.pos
+    summary.adj <- c(0, 1)
+  } else if(summary.pos[1] == "topleft") {
+    summary.pos <- c(xlim.plot[1], ylim.plot[4])
+    summary.adj <- c(0, 1)
+  } else if(summary.pos[1] == "top") {
+    summary.pos <- c(mean(xlim.plot), ylim.plot[4])
+    summary.adj <- c(0.5, 1)
+  } else if(summary.pos[1] == "topright") {
+    summary.pos <- c(xlim.plot[2], ylim.plot[4])
+    summary.adj <- c(1, 1)
+  }  else if(summary.pos[1] == "left") {
+    summary.pos <- c(xlim.plot[1], mean(ylim.plot[3:4]))
+    summary.adj <- c(0, 0.5)
+  } else if(summary.pos[1] == "center") {
+    summary.pos <- c(mean(xlim.plot), mean(ylim.plot[3:4]))
+    summary.adj <- c(0.5, 0.5)
+  } else if(summary.pos[1] == "right") {
+    summary.pos <- c(xlim.plot[2], mean(ylim.plot[3:4]))
+    summary.adj <- c(1, 0.5)
+  }else if(summary.pos[1] == "bottomleft") {
+    summary.pos <- c(xlim.plot[1], ylim.plot[3])
+    summary.adj <- c(0, 0)
+  } else if(summary.pos[1] == "bottom") {
+    summary.pos <- c(mean(xlim.plot), ylim.plot[3])
+    summary.adj <- c(0.5, 0)
+  } else if(summary.pos[1] == "bottomright") {
+    summary.pos <- c(xlim.plot[2], ylim.plot[3])
+    summary.adj <- c(1, 0)
+  }
   
-  if(missing(summary.pos)==TRUE) {summary.pos <- c(xlim.plot[1], 
-                                                   max(values[,2]))}
-  
+  ## add summary text
   text(x = summary.pos[1],
        y = summary.pos[2],
-       adj = c(0, 1),
+       adj = summary.adj,
        labels = label.text,
        col = "black", 
        cex = 0.8 * cex.global)
@@ -278,6 +351,8 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
 }, ex=function(){
   ## load data
   data(ExampleData.DeValues, envir = environment())
+  ExampleData.DeValues <- 
+    Second2Gray(values = ExampleData.DeValues, dose_rate = c(0.0438,0.0019))
   
   ## plot histogram the easiest way
   plot_Histogram(ExampleData.DeValues)
@@ -290,10 +365,11 @@ plot_Histogram <- structure(function(# Plot a histogram with a separate error pl
                  pch = 2,
                  colour = c("grey", "black", "blue", "green"),
                  summary = c("n", "mean", "sdrel"),
-                 summary.pos = c(3500, 140),
+                 summary.pos = "topleft",
                  main = "Histogram of De-values",
                  mtext = "Example data set", 
-                 ylab = c(expression(paste(D[e], " Distribution")),
-                          "Std.-err."),
-                 xlim = c(1800, 4000))
+                 ylab = c(expression(paste(D[e], " distribution")),
+                          "Error"),
+                 xlim = c(100, 250),
+                 ylim = c(0, 0.08, 50, 200))
 })
\ No newline at end of file
